# aiobrawlstats - Easy Async library for working with BrawlStars API

> #### Что нужно, чтобы пользоваться библиотекой:
>#### [PyCharm](https://www.jetbrains.com/ru-ru/pycharm/)
>#### [BrawlStars Token](https://developer.brawlstars.com/#/new-key)

#### Установка:

```sh
pip install -U aiobrawlstats
pip install -U https://github.com/vladislavkovalskyi/aiobrawlstats/archive/master.zip
```